@@ -26,7 +26,7 @@ class AnalitzaDeclarativePlugin : public QQmlExtensionPlugin
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 public:
-    virtual void registerTypes(const char* uri);
+    virtual void registerTypes(const char* uri) override;
 };
 
 #endif // ANALITZADECLARATIVEPLUGIN_H
